@@ -1,5 +1,3 @@
-### @todo Add a copyright and license notice in all files
-
 import httplib
 import json
 import base64
@@ -19,7 +17,8 @@ class Requester:
         headers, output = self.__statusCheckedRequest( verb, url, parameters, input )
 
         obviouslyFinished = False
-        while "link" in headers and "next" in headers[ "link" ] and not obviouslyFinished:
+        pageCount = 1
+        while "link" in headers and "next" in headers[ "link" ] and not obviouslyFinished and pageCount < 10:
             for link in headers[ "link" ].split( "," ):
                 if "next" in link:
                     linkUrl = link.split( ";" )[ 0 ][ : -1 ]
@@ -27,6 +26,7 @@ class Requester:
                     parameters.update( dict( p.split( "=" ) for p in params.split( "&" ) ) )
                     break
             headers, newOutput = self.__statusCheckedRequest( verb, url, parameters, input )
+            pageCount += 1
             if len( newOutput ) == 0:
                 obviouslyFinished = True
             output += newOutput
@@ -36,7 +36,6 @@ class Requester:
     def __statusCheckedRequest( self, verb, url, parameters, input ):
         status, headers, output = self.__rawRequest( verb, url, parameters, input )
         if status < 200 or status >= 300:
-            ### @todo Be specific (403 is not the same thing as 404!)
             raise UnknownGithubObject()
         return headers, output
 
